"""
Messaging is a set of Python modules useful to deal with
*messages*, as used in messaging, see for instance:
http://en.wikipedia.org/wiki/Enterprise_messaging_system.

The modules include a transport independent message abstraction, a
versatile message generator and several message queues/spools to
locally store messages.

You can download the module at the following link:
http://pypi.python.org/pypi/messaging/

An Perl implementation of the same abstractions and queue algorithms
is available at the following page:
http://search.cpan.org/dist/Messaging-Message/

Copyright (C) CERN 2013-2021
"""

AUTHOR = "Massimo Paladin <massimo.paladin@gmail.com>"
VERSION = "1.2"
DATE = "3 Nov 2021"
__author__ = AUTHOR
__version__ = VERSION
__date__ = DATE
